<?php
namespace Teknisa\CADPED\Factories;

class Ger00700ClienteFactory {
    protected $connection;

    public function __construct($entityManager) {
        #initializes default service
        $this->connection = $entityManager->getConnection();
        $this->entityManager    = $entityManager;
    }

    public function selectAllFormasPagamento($nrorg, $cdcliente) {
        $sql = "SELECT NRORG, CDCLIENTE
                FROM PRAZOPGTCLIE
                WHERE NRORG         = :NRORG
                  AND CDCLIENTE     = :CDCLIENTE";

        $params = array('NRORG'         =>$nrorg,
                        'CDCLIENTE'     =>$cdcliente);

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function deleteFormaPagamento($nrorg, $cdcliente) {
        $sql = "DELETE FROM PRAZOPGTCLIE
                WHERE NRORG           = :NRORG
                    AND CDCLIENTE     = :CDCLIENTE";

        $params = array('NRORG'         => $nrorg,
                        'CDCLIENTE'     => $cdcliente);

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deletaPrazo($rows)
    {
        try{
            $this->connection->beginTransaction();
            $sql = "DELETE FROM PRAZOPGTCLIE
                    WHERE CDCLIENTE = :P_CDCLIENTE";
                   
            $param['P_CDCLIENTE']  = $rows[0]['CDCLIENTE'];
    
            $std = $this->connection->prepare($sql);
            $std->execute($param);
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->entityManager->rollback();
            throw $e;
        }

    }
    
    public function insertPrazo ($row, $param)
    {
		
        $param['P_CDCLIENTE']   = $row['CDCLIENTE'];
        $param['P_NRDIASPGTOCL'] = $row['NRDIASPGTOCL'];
        $param['P_VRPERCPGTOCL'] = $row['VRPERCPGTOCL'];
        $param['P_IDATIVO']      = 'S';
        
        $query = "INSERT INTO PRAZOPGTCLIE 
                    (CDCLIENTE, 
                    NRDIASPGTOCL, 
                    VRPERCPGTOCL, 
                    DTULTATUPCLI,
                    NRORG,
                    DTINCLUSAO,
                    DTULTATU,
                    NRORGINCLUSAO,
                    CDOPERINCLUSAO,
                    NRORGULTATU,
                    CDOPERULTATU,
                    IDATIVO) 
                  VALUES 
                    (:P_CDCLIENTE, 
                    :P_NRDIASPGTOCL,
                    :P_VRPERCPGTOCL,
                    (SYSDATE),
                    :P_NRORG,
                    (SYSDATE),
                    (SYSDATE),
                    :P_NRORG,
                    :P_CDOPERADOR,
                    :P_NRORG,
                    :P_CDOPERADOR,
                    :P_IDATIVO)";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
        } catch (Exception $e){
            throw $e;
        }  
    }
    
    public function updatePrazo ($row)
    {
        
		$param = array();
    	
        $param['P_CDCLIENTE']     = $row['CDCLIENTE'];
        $param['P_NRDIASPGTOCL']   = $row['NRDIASPGTOCL'];
        $param['P_VRPERCPGTOCL']   = $row['VRPERCPGTOCL'];
        $param['OLD_NRDIASPGTOCL'] = isset($row['changed_NRDIASPGTOCL']) ? $row['changed_NRDIASPGTOCL'] : $row['NRDIASPGTOCL'];
        $param['OLD_VRPERCPGTOCL'] = isset($row['changed_VRPERCPGTOCL']) ? $row['changed_VRPERCPGTOCL'] : $row['VRPERCPGTOCL'];
        $param['P_CDOPERADOR']     = $this->environment->getCdoperador();
        
        $sql = "UPDATE PRAZOPGTCLIE SET
                    NRDIASPGTOCL = :P_NRDIASPGTOCL, 
                    VRPERCPGTOCL = :P_VRPERCPGTOCL,
                    DTULTATU = (SYSDATE),
                    CDOPERULTATU = :P_CDOPERADOR
                  WHERE
                    CDCLIENTE = :P_CDCLIENTE
                    AND NRDIASPGTOCL = :OLD_NRDIASPGTOCL
                    AND VRPERCPGTOCL = :OLD_VRPERCPGTOCL";
                    
        try {
            $std = $this->connection->prepare($sql);
            $std->execute($param);
        } catch (Exception $e){
            throw $e;
        }  
    }
    
    public function salvarCompacArq ($row) {
		$param = array();
		$param['P_IDCOMPARQXMLCLI'] = $row['IDCOMPARQXMLCLI'];
        $param['P_CDCLIENTE'] = $row['CDCLIENTE'];
        
        
        if(empty(self::retornaDadosCompacArq($row))){
            $query = "INSERT INTO CLIENTE (IDCOMPARQXMLCLI) VALUES (:P_IDCOMPARQXMLCLI) WHERE CDCLIENTE = :P_CDCLIENTE";
            try {
                $std = $this->connection->prepare($query);
                $std->execute($param);
            } catch (Exception $e){
                throw $e;
            }  
        }else{
            $query = "UPDATE CLIENTE SET IDCOMPARQXMLCLI = :P_IDCOMPARQXMLCLI WHERE CDCLIENTE = :P_CDCLIENTE";
            try {
                $std = $this->connection->prepare($query);
                $std->execute($param);
            } catch (Exception $e){
                throw $e;
            } 
        }
    }
}